@@ -31,7 +31,7 @@ our @EXPORT = qw(
 
 );
 
-our $VERSION = '0.05_02';
+our $VERSION = '0.02';
 
 =head1 NAME
 
@@ -79,19 +79,13 @@ AntTweakBar - Perl bindings for AntTweakBar
 
 =head1 DESCRIPTION
 
-=for HTML
-<p>
-  <img src="https://raw.githubusercontent.com/PerlGameDev/AntTweakBar/master/eg/available-properties.png" style="max-width:100%;">
-  <img src="https://raw.githubusercontent.com/PerlGameDev/AntTweakBar/master/eg/simple-glut.gif" style="max-width:100%;">
+=for HTML <p>
+<img src="http://anttweakbar.sourceforge.net/doc/data/media/tools/anttweakbar/twsimplesdl-128.jpg" style="max-width:100%;">
 </p>
 
-
 AntTweakBar (see L<http://anttweakbar.sourceforge.net/>) is nice tiny
 GUI library for OpenGL/SDL/DirectX applications.
 
-If you are in hurry to evaluate it then intall AntTweakBar and try
-examples from C<eg> directory within the distribution.
-
 To display AntTweakBar in your OpenGL/SDL application you should do the
 following:
 
@@ -121,7 +115,7 @@ following:
     mode       => 'rw',
     name       => "Enabled",
     type       => 'integer',
-    value      => \$value
+    value      => \$enabled
   );
 
 =back
@@ -199,16 +193,6 @@ sub DESTROY {
 }
 
 
-sub _as_definition_string {
-    my $d = shift;
-    return join(' ', map {
-        my $key = $_;
-        my $value = $d->{$key};
-        $value =~ s/'/\\'/g;
-        "$key='$value'";
-    } sort keys %$d);
-}
-
 =head2 add_button
 
   $bar->add_button(
@@ -217,21 +201,11 @@ sub _as_definition_string {
     definition => "label='Click me!'",    # optional
   );
 
-  $bar->add_button(
-    name       => 'my_btn',
-    cb         => sub { say "clicked!" },
-    definition => { # optional
-      label => 'Click me!'
-    }
-  );
-
-
 The definition parameters are the same as for variable. See
 L<http://anttweakbar.sourceforge.net/doc/tools:anttweakbar:varparamsyntax#parameters>.
 
 =cut
 
-
 sub add_button {
     my ($self, %args) = @_;
 
@@ -243,8 +217,6 @@ sub add_button {
         unless defined $name;
     croak "Button callback should be specified"
         if(!defined($cb) || ref($cb) ne 'CODE');
-    $definition = _as_definition_string($definition)
-        if ($definition && ref($definition) eq 'HASH');
 
     _add_button($self->{_bar_ptr}, $name, $cb, $definition);
 }
@@ -262,8 +234,6 @@ sub add_separator {
         unless defined $name;
 
     $definition //= "";
-    $definition = _as_definition_string($definition)
-        if ($definition && ref($definition) eq 'HASH');
 
     _add_separator($self->{_bar_ptr}, $name, $definition);
 }
@@ -280,22 +250,6 @@ sub add_separator {
     definition => " min=0.01 max=2.5 step=0.01 help='Bla-bla-bla.' ",
   );
 
-  # the same, but with more perlish style in definition
-  $bar->add_variable(
-    mode       => 'rw',
-    name       => "Zoom",
-    type       => 'number',
-    value      => \$zoom,
-    definition => {
-        min     => "0.01",
-        max     => "2.5",
-        step    => "0.01",
-        keyIncr => 'z',
-        keyDecr => 'Z',
-        help    => 'Scale the object (1=original size).'
-    },
-  );
-
   my $bool = undef;
   $bar->add_variable(
     mode       => 'rw',
@@ -325,7 +279,7 @@ for the variable.
 =head3 type
 
 Defines the type of variable. Original types L<http://anttweakbar.sourceforge.net/doc/tools:anttweakbar:twtype>
-were reduced to:
+has been reduced to:
 
 =over
 
@@ -373,8 +327,7 @@ If C<cb_write> is undefined, then the variable considered B<readonly>.
 
 =head3 definition
 
-An string or hashref of values that allows additional tuning of
-variable in Anttweakbar.
+An string that allows additiona tuning of variable.
 See L<http://anttweakbar.sourceforge.net/doc/tools:anttweakbar:varparamsyntax#parameters>
 for possible values.
 
@@ -403,8 +356,6 @@ sub add_variable {
     croak "value should be a reference"
         if ($value && !ref($value));
     $type = $type->name if(ref($type) eq 'AntTweakBar::Type');
-    $definition = _as_definition_string($definition)
-        if ($definition && ref($definition) eq 'HASH');
 
     _add_variable($self->{_bar_ptr}, $mode, $name, $type, $value,
                   $cb_read, $cb_write, $definition);
@@ -552,13 +503,6 @@ L<Alien::AntTweakBar>, L<SDL>, L<OpenGL>, L<http://anttweakbar.sourceforge.net/>
 
 Ivan Baidakou E<lt>dmol@(gmx.com)E<gt>
 
-=head1 CREDITS
-
-=over 2
-
-David Horner
-
-=back
 
 =head1 COPYRIGHT AND LICENSE
 
